@@ -255,10 +255,20 @@ class FuncNode:
     def __hash__(self):
         return hash(self._hash_str())
 
+    def __lt__(self, other):
+        return hash(self) < hash(other)
+
+    def __gt__(self, other):
+        return hash(self) > hash(other)
+
     def __call__(self, scope):
         """Deprecated: Don't use. Might be a normal function with a signature"""
         return self.call_on_scope(scope)
 
+    # See https://github.com/i2mint/meshed/issues/21 (not 12!)
+    # def __eq__(self, other):
+    #     return hash(self) == hash(other)
+
     @classmethod
     def has_as_instance(cls, obj):
         """Verify if ``obj`` is an instance of a FuncNode (or specific sub-class).
@@ -351,6 +361,47 @@ def is_not_func_node(obj) -> bool:
     return not FuncNode.has_as_instance(obj)
 
 
+def get_init_params_of_instance(obj):
+    """Get names of instance object ``obj`` that are also parameters of the
+    ``__init__`` of its class"""
+    return {k: v for k, v in vars(obj).items() if k in Sig(type(obj)).names}
+
+
+def ch_func_node_attrs(fn, **new_attrs_values):
+    """Returns a copy of the func node with some of it's attributes changed
+
+    >>> def plus(a, b):
+    ...     return a + b
+    ...
+    >>> def minus(a, b):
+    ...     return a - b
+    ...
+    >>> fn = FuncNode(func=plus, out='sum')
+    >>> fn.func == plus
+    True
+    >>> fn.name == 'plus'
+    True
+    >>> new_fn = ch_func_node_attrs(fn, func=minus)
+    >>> new_fn.func == minus
+    True
+    >>> new_fn.synopsis_string() == 'a,b -> plus -> sum'
+    True
+    >>>
+    >>>
+    >>> newer_fn = ch_func_node_attrs(fn, func=minus, name='sub', out='difference')
+    >>> newer_fn.synopsis_string() == 'a,b -> sub -> difference'
+    True
+    """
+    init_params = get_init_params_of_instance(fn)
+    if params_that_are_not_init_params := (new_attrs_values.keys() - init_params):
+        raise ValueError(
+            f'These are not params of {type(fn).__name__}: '
+            f'{params_that_are_not_init_params}'
+        )
+    fn_kwargs = dict(init_params, **new_attrs_values)
+    return FuncNode(**fn_kwargs)
+
+
 def _keys_and_values_are_strings_validation(d: dict):
     for k, v in d.items():
         if not isinstance(k, str):
@@ -482,3 +533,55 @@ def _complete_dict_with_iterable_of_required_keys(
     for required_key in complete_with:
         if required_key not in keys_already_covered:
             to_complete[required_key] = required_key
+
+
+from typing import NewType, Dict, Tuple, Mapping
+
+# TODO: Make a type where ``isinstance(s, Identifier) == s.isidentifier()``
+Identifier = NewType('Identifier', str)  # + should satisfy str.isidentifier
+Bind = NewType(
+    'Bind',
+    Union[
+        str,  # Identifier or ' '.join(Iterable[Identifier])
+        Dict[Identifier, Identifier],
+        Sequence[Union[Identifier, Tuple[Identifier, Identifier]]],
+    ],
+)
+IdentifierMapping = Dict[Identifier, Identifier]
+
+
+def identifier_mapping(x: Bind) -> IdentifierMapping:
+    """Get an ``IdentifierMapping`` dict from a more loosely defined ``Bind``.
+
+    You can get an identifier mapping (that is, an explicit for for a ``bind`` argument)
+    from...
+
+    ... a single space-separated string
+
+    >>> identifier_mapping('x a_b yz')  #
+    {'x': 'x', 'a_b': 'a_b', 'yz': 'yz'}
+
+    ... an iterable of strings or pairs of strings
+
+    >>> identifier_mapping(['foo', ('bar', 'mitzvah')])
+    {'foo': 'foo', 'bar': 'mitzvah'}
+
+    ... a dict will be considered to be the mapping itself
+
+    >>> identifier_mapping({'x': 'y', 'a': 'b'})
+    {'x': 'y', 'a': 'b'}
+    """
+    if isinstance(x, str):
+        x = x.split()
+    if not isinstance(x, Mapping):
+
+        def gen():
+            for item in x:
+                if isinstance(item, str):
+                    yield item, item
+                else:
+                    yield item
+
+        return dict(gen())
+    else:
+        return dict(**x)
