@@ -433,7 +433,7 @@ def modified_func_node(func_node, **modifications) -> FuncNode:
     return FuncNode(**dict(original_func_node_kwargs, **modifications))
 
 
-from meshed.util import partialx
+from i2 import partialx
 
 # TODO: doctests
 def partialized_funcnodes(func_nodes, **keyword_defaults):
@@ -460,6 +460,11 @@ Scope = dict
 VarNames = Iterable[str]
 DagOutput = Any
 
+
+def _name_attr_or_x(x):
+    return getattr(x, 'name', x)
+
+
 # TODO: caching last scope isn't really the DAG's direct concern -- it's a debugging
 #  concern. Perhaps a more general form would be to define a cache factory defaulting
 #  to a dict, but that could be a "dict" that logs writes (even to an attribute of self)
@@ -896,6 +901,16 @@ class DAG:
                 # ``parameter_merge`` with raise an error.
                 yield self.parameter_merge(params_with_name_changed_to_src_name)
 
+    @property
+    def graph_ids(self):
+        """The dict representing the ``{from_node: to_nodes}`` graph.
+        Like ``.graph``, but with node ids (names).
+        """
+        return {
+            _name_attr_or_x(k): list(map(_name_attr_or_x, v))
+            for k, v in self.graph.items()
+        }
+
     # ------------ display --------------------------------------------------------------
 
     def synopsis_string(self):
